jQuery(document).ready(function () {
  (function(document, window) {

    var $osPage = jQuery('#omnistream_page');
    var postGuid = $osPage.data('post-guid');
    var pageGuid = $osPage.data('page-guid');

    function trackActionEvent(params) {
      return jQuery.ajax({
        method: 'POST',
        url: omnistreamConnectorVars.trackerUrl + '/v1/events',
        data: jQuery.extend({
          article: postGuid,
          unit: pageGuid,
          location: window.location.href, // the full URL of the current page
          referrer: document.referrer,    // the full URL of the previous page
          referrer_article: postGuid      // used for ad-click event, ignored by server otherwise
        }, params),
        xhrFields: {
          withCredentials: true
        }
      });
    }

    function trackPageLoadAndTimeSpent($el) {
      var guid = $el.data('post-guid')
      if (guid) {
        trackActionEvent({ name: 'page-load' }).then(function(response) {
          // response includes id and token of the event created, required to update the heartbeat time of the event later
          var heartbeatsRemaining = 20;
          var heartbeatDelay = 10000;
          var loadedAt = new Date().getTime()

          setTimeout(function sendHeartbeat() {
            if (new Date().getTime() - loadedAt < 11 * 60 * 1000) {
              jQuery.ajax({
                method: 'PUT',
                url: omnistreamConnectorVars.trackerUrl + '/v1/events/' + response.id,
                data: {
                  token: response.token
                },
                xhrFields: {
                  withCredentials: true
                }
              }).then(function() {
                heartbeatsRemaining--;
                if (heartbeatsRemaining > 0) {
                  heartbeatDelay = heartbeatDelay * 1.1; // +10% delay each time
                  setTimeout(sendHeartbeat, heartbeatDelay);
                }
              });
            }
          }, heartbeatDelay);
        });
      }
    }

    trackPageLoadAndTimeSpent($osPage);
    trackPageLoadAndTimeSpent(jQuery('.ad-header a'));

    jQuery('.omnistream_content a, a[data-event]').on('click', function(e) {
      var $link = jQuery(e.target);
      var href = $link.attr('href');

      if (! href || href.match(/^https?:\/\/(?:staging-)?tracker\b/))
        return; // no tracking for this link

      var sameWindow = $link.attr('target') != '_blank';

      trackActionEvent({
        name: $link.data('event') || 'hyperlink',
        article: $link.data('post-guid'), // for ads, trackActionEvent() uses postGuid if this is undefined
        location: href,
        referrer: window.location.href
      }).then(function() {
        if (sameWindow) {
          window.location = href; // navigate to URL after tracking finishes
        }
      });

      if (sameWindow) {
        // prevent following link until event is logged
        return false;
      }
    });

    try {
      var node = document.createElement('script');
      node.src =  omnistreamConnectorVars.trackerUrl + '/omni-logger.js';
      node.setAttribute('org', omnistreamConnectorVars.unitId);
      node.setAttribute('data-search-fields', omnistream.logSelector());
      node.setAttribute('data-identity', omnistream.logIdentity());
      node.setAttribute('data-location', omnistream.logLocation());
      document.getElementsByTagName('head')[0].appendChild(node);
    } catch(err) { console.log('Unable to log search string', err) }

  })(document, window);
});
